CREATE TABLE `ITscope_ProductTypeGroup`
(
    `id`   VARCHAR(3)   NOT NULL,
    `name` VARCHAR(255) NOT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ProductType`
(
    `id`                    BIGINT(20)   NOT NULL,
    `productTypeGroupRefId` VARCHAR(3)   NOT NULL,
    `name`                  VARCHAR(255) NOT NULL,
    `attributeTypeId1`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeName1`    VARCHAR(255) DEFAULT NULL,
    `attributeTypeId2`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeName2`    VARCHAR(255) DEFAULT NULL,
    `attributeTypeId3`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeName3`    VARCHAR(255) DEFAULT NULL,
    `attributeTypeId4`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeName4`    VARCHAR(255) DEFAULT NULL,
    `attributeTypeId5`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeName5`    VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`, `productTypeGroupRefId`),
    KEY `producttype_producttypegroup` (`productTypeGroupRefId`),
    CONSTRAINT `producttype_producttypegroup` FOREIGN KEY (`productTypeGroupRefId`) REFERENCES `ITscope_ProductTypeGroup` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_Supplier`
(
    `id`                    BIGINT(20)    NOT NULL,
    `name`                  VARCHAR(255)  NOT NULL,
    `deeplink`              VARCHAR(2048) NOT NULL,
    `customerAccountNumber` VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_Manufacturer`
(
    `id`        BIGINT(20)    NOT NULL,
    `name`      VARCHAR(255)  NOT NULL,
    `shortName` VARCHAR(255)  NOT NULL,
    `deeplink`  VARCHAR(2048) NOT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ContentProvider`
(
    `id`   BIGINT(20) NOT NULL,
    `name` VARCHAR(255) DEFAULT NULL,
    `rank` INT(11)      DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ContentModel`
(
    `id`   BIGINT(20) NOT NULL,
    `name` VARCHAR(1024) DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ContentCategory`
(
    `id`   BIGINT(20) NOT NULL,
    `name` VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ContentTag`
(
    `id`     BIGINT(20) NOT NULL,
    `name`   VARCHAR(40) DEFAULT NULL,
    `rank`   INT(11)     DEFAULT NULL,
    `source` VARCHAR(10) DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_AttributeCluster`
(
    `id`                     BIGINT(20) NOT NULL,
    `productTypeId`          BIGINT(20)   DEFAULT NULL,
    `name`                   VARCHAR(255) DEFAULT NULL,
    `min`                    VARCHAR(255) DEFAULT NULL,
    `max`                    VARCHAR(255) DEFAULT NULL,
    `rank`                   BIGINT(20)   DEFAULT NULL,
    `attributeTypeId`        BIGINT(20)   DEFAULT NULL,
    `attributeTypeName`      VARCHAR(255) DEFAULT NULL,
    `attributeTypeRank`      BIGINT(20)   DEFAULT NULL,
    `attributeTypeUnit`      VARCHAR(100) DEFAULT NULL,
    `attributeTypeGroupId`   VARCHAR(20)  DEFAULT NULL,
    `attributeTypeGroupName` VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`),
    KEY `ac_productTypeId` (`productTypeId`),
    CONSTRAINT `ac_productTypeId` FOREIGN KEY (`productTypeId`) REFERENCES `ITscope_ProductType` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;


CREATE TABLE `ITscope_Product`
(
    `puid`                      BIGINT(20)    NOT NULL,
    `ean`                       VARCHAR(18)   DEFAULT NULL,
    `manufacturerSKU`           VARCHAR(150)  DEFAULT NULL,
    `icecatID`                  VARCHAR(255)  DEFAULT NULL,
    `cnetID`                    VARCHAR(255)  DEFAULT NULL,
    `bechlemID`                 VARCHAR(255)  DEFAULT NULL,
    `eClass`                    VARCHAR(255)  DEFAULT NULL,
    `eClassV7`                  VARCHAR(255)  DEFAULT NULL,
    `customsTariffNumber`       VARCHAR(255)  DEFAULT NULL,
    `UNSPSC`                    VARCHAR(255)  DEFAULT NULL,
    `manufacturerId`            BIGINT(20)    NOT NULL,
    `productName`               VARCHAR(2000) NOT NULL,
    `shortDescription`          TEXT          DEFAULT NULL,
    `longDescription`           TEXT          DEFAULT NULL,
    `productTypeId`             BIGINT(20)    NOT NULL,
    `attributeValue1`           VARCHAR(1024) DEFAULT NULL,
    `attributeValue2`           VARCHAR(1024) DEFAULT NULL,
    `attributeValue3`           VARCHAR(1024) DEFAULT NULL,
    `attributeValue4`           VARCHAR(1024) DEFAULT NULL,
    `attributeValue5`           VARCHAR(1024) DEFAULT NULL,
    `productSubTypeId`          VARCHAR(1024) DEFAULT NULL,
    `productSubType`            VARCHAR(1024) DEFAULT NULL,
    `productLineId`             BIGINT(20)    DEFAULT NULL,
    `productLine`               VARCHAR(1024) DEFAULT NULL,
    `productModel`              VARCHAR(1024) DEFAULT NULL,
    `colorFamilyId`             VARCHAR(255)  DEFAULT NULL,
    `colorFamily`               VARCHAR(255)  DEFAULT NULL,
    `estimateGrossWeight`       DOUBLE        DEFAULT NULL,
    `grossDimX`                 VARCHAR(1024) DEFAULT NULL,
    `grossDimY`                 VARCHAR(1024) DEFAULT NULL,
    `grossDimZ`                 VARCHAR(1024) DEFAULT NULL,
    `combinedLengthAndGirth`    VARCHAR(36)   DEFAULT NULL,
    `netWeight`                 VARCHAR(36)   DEFAULT NULL,
    `netDimX`                   VARCHAR(36)   DEFAULT NULL,
    `netDimY`                   VARCHAR(36)   DEFAULT NULL,
    `netDimZ`                   VARCHAR(36)   DEFAULT NULL,
    `valueAddedTaxGermany`      INT(11)       DEFAULT NULL,
    `deeplink`                  VARCHAR(2048) NOT NULL,
    `standardHtmlDatasheet`     VARCHAR(2048) NOT NULL,
    `standardPdfDatasheet`      VARCHAR(2048) DEFAULT NULL,
    `manufacturerSite`          VARCHAR(1024) DEFAULT NULL,
    `manufacturerDatasheet`     VARCHAR(1024) DEFAULT NULL,
    `imageThumb`                VARCHAR(1024) DEFAULT NULL,
    `imageThumbWidth`           INT(11)       DEFAULT NULL,
    `imageThumbHeight`          INT(11)       DEFAULT NULL,
    `image1`                    VARCHAR(1024) DEFAULT NULL,
    `imageWidth1`               INT(11)       DEFAULT NULL,
    `imageHeight1`              INT(11)       DEFAULT NULL,
    `image2`                    VARCHAR(1024) DEFAULT NULL,
    `imageWidth2`               INT(11)       DEFAULT NULL,
    `imageHeight2`              INT(11)       DEFAULT NULL,
    `image3`                    VARCHAR(1024) DEFAULT NULL,
    `imageWidth3`               INT(11)       DEFAULT NULL,
    `imageHeight3`              INT(11)       DEFAULT NULL,
    `image4`                    VARCHAR(1024) DEFAULT NULL,
    `imageWidth4`               INT(11)       DEFAULT NULL,
    `imageHeight4`              INT(11)       DEFAULT NULL,
    `image5`                    VARCHAR(1024) DEFAULT NULL,
    `imageWidth5`               INT(11)       DEFAULT NULL,
    `imageHeight5`              INT(11)       DEFAULT NULL,
    `energyLabel`               VARCHAR(1024) DEFAULT NULL,
    `energyEfficiencyClass`     VARCHAR(10)   DEFAULT NULL,
    `entryDate`                 DATETIME      NOT NULL,
    `rank`                      INT(11)       DEFAULT NULL,
    `qualification`             INT(11)       DEFAULT NULL,
    `warrantyText`              TEXT          DEFAULT NULL,
    `marketingText`             TEXT          DEFAULT NULL,
    `keySellingPoints`          TEXT          DEFAULT NULL,
    `packageContents`           TEXT          DEFAULT NULL,
    `productFeatures`           TEXT          DEFAULT NULL,
    `htmlMainSpecs`             TEXT          DEFAULT NULL,
    `htmlSpecs`                 TEXT          DEFAULT NULL,
    `recommendedRetailPriceNet` DOUBLE        DEFAULT NULL,
    `aggregatedStatus`          INT(11)       NOT NULL,
    `aggregatedStatusText`      VARCHAR(255)  NOT NULL,
    `aggregatedStock`           INT(11)       NOT NULL,
    `aggregatedSupplierItems`   INT(11)       NOT NULL,
    `contractTypeId`            INT(11)       NOT NULL,
    `contractTypeName`          VARCHAR(255)   NOT NULL,
    PRIMARY KEY (`puid`),
    KEY `pro_productTypeId` (`productTypeId`),
    KEY `pro_manufacturerId` (`manufacturerId`),
    CONSTRAINT `pro_productTypeId` FOREIGN KEY (`productTypeId`) REFERENCES `ITscope_ProductType` (`id`),
    CONSTRAINT `pro_manufacturerId` FOREIGN KEY (`manufacturerId`) REFERENCES `ITscope_Manufacturer` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;


CREATE TABLE `ITscope_ProductPriceInfo`
(
    `productId`           BIGINT(20)   NOT NULL,
    `price`               DOUBLE       NOT NULL,
    `priceCalc`           DOUBLE       NOT NULL,
    `currencyCode`        VARCHAR(3)   NOT NULL,
    `priceCalcVat`        DOUBLE       NOT NULL,
    `priceLastUpdate`     DATETIME     NOT NULL,
    `minScale`            INT(11)      NOT NULL,
    `priceSourceId`       INT(11)      NOT NULL,
    `priceSourceName`     VARCHAR(255) NOT NULL,
    `priceStatus`         VARCHAR(255) NOT NULL,
    `priceSupplierId`     BIGINT(20)   NOT NULL,
    `priceSupplierName`   VARCHAR(255) NOT NULL,
    `priceSupplierItemId` BIGINT(20)   NOT NULL,
    `priceSupplierSKU`    VARCHAR(150) NOT NULL,
    `priceBillingPeriod`        INT(11)       DEFAULT NULL,
    `priceBillingPeriodUnit`    VARCHAR(40)   DEFAULT NULL,
    `priceSubscriptionPeriod`   INT(11)       DEFAULT NULL,
    `priceSubscriptionPeriodUnit` VARCHAR(40) DEFAULT NULL,
    PRIMARY KEY (`productId`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ProductStockInfo`
(
    `productId`             BIGINT(20)   NOT NULL,
    `stockSupplierText`     VARCHAR(40) DEFAULT NULL,
    `stockStatus`           INT(11)      NOT NULL,
    `stockStatusText`       VARCHAR(255) NOT NULL,
    `stock`                 INT(11)      NOT NULL,
    `externalStock`         INT(11)     DEFAULT NULL,
    `incomingStock`         INT(11)     DEFAULT NULL,
    `stockAvailabilityDate` DATETIME    DEFAULT NULL,
    `stockLastUpdate`       DATETIME     NOT NULL,
    `stockSourceId`         INT(11)      NOT NULL,
    `stockSourceName`       VARCHAR(255) NOT NULL,
    `stockUnlimited`        VARCHAR(5)   NOT NULL,
    PRIMARY KEY (`productId`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_Products2Cluster`
(
    `productRefId`          BIGINT(20) NOT NULL,
    `attributeClusterRefId` BIGINT(20) NOT NULL,
    PRIMARY KEY (`productRefId`, `attributeClusterRefId`),
    KEY `xref_cluster` (`attributeClusterRefId`),
    CONSTRAINT `xref_cluster` FOREIGN KEY (`attributeClusterRefId`) REFERENCES `ITscope_AttributeCluster` (`id`),
    CONSTRAINT `xref_product` FOREIGN KEY (`productRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;


CREATE TABLE `ITscope_SupplierItem`
(
    `id`                        BIGINT(20)   NOT NULL,
    `productId`                 BIGINT(20)   NOT NULL,
    `ean`                       VARCHAR(18)   DEFAULT NULL,
    `manufacturerSKU`           VARCHAR(150)  DEFAULT NULL,
    `supplierSKU`               VARCHAR(150)  DEFAULT NULL,
    `supplierId`                BIGINT(20)   NOT NULL,
    `manufacturerName`          VARCHAR(80)   DEFAULT NULL,
    `productName`               VARCHAR(255)  DEFAULT NULL,
    `longDescription`           TEXT          DEFAULT NULL,
    `conditionId`               INT(11)      NOT NULL,
    `conditionName`             VARCHAR(255) NOT NULL,
    `eolProduct`                VARCHAR(5)   NOT NULL,
    `matchQuality`              INT(11)      NOT NULL,
    `eanValid`                  VARCHAR(5)   NOT NULL,
    `specialOffer`              VARCHAR(5)   NOT NULL,
    `promotion`                 VARCHAR(40)   DEFAULT NULL,
    `vat`                       INT(11)       DEFAULT NULL,
    `copyrightLevy`             DOUBLE        DEFAULT NULL,
    `customsTariffNumber`       VARCHAR(50)   DEFAULT NULL,
    `countryOfOrigin`           VARCHAR(20)   DEFAULT NULL,
    `grossDimX`                 DOUBLE        DEFAULT NULL,
    `grossDimY`                 DOUBLE        DEFAULT NULL,
    `grossDimZ`                 DOUBLE        DEFAULT NULL,
    `warrantyText`              VARCHAR(40)   DEFAULT NULL,
    `deeplink`                  VARCHAR(1024) DEFAULT NULL,
    `recommendedRetailPriceNet` DOUBLE        DEFAULT NULL,
    `contractTypeId`            INT(11)      NOT NULL,
    `contractTypeName`          VARCHAR(20)  NOT NULL,
    PRIMARY KEY (`productId`, `id`),
    KEY `si_supplier` (`supplierId`),
    CONSTRAINT `si_supplier` FOREIGN KEY (`supplierId`) REFERENCES `ITscope_Supplier` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

ALTER TABLE ITscope_SupplierItem
    ADD INDEX (id);

CREATE TABLE `ITscope_SupplierPriceInfo`
(
    `priceSupplierItemId` BIGINT(20)   NOT NULL,
    `price`               DOUBLE       NOT NULL,
    `priceCalc`           DOUBLE       NOT NULL,
    `currencyCode`        VARCHAR(3)   NOT NULL,
    `priceCalcVat`        DOUBLE       NOT NULL,
    `priceLastUpdate`     DATETIME     NOT NULL,
    `minScale`            INT(11)      NOT NULL,
    `priceSourceId`       INT(11)      NOT NULL,
    `priceSourceName`     VARCHAR(255) NOT NULL,
    `priceStatus`         VARCHAR(255) NOT NULL,
    `priceBillingPeriod`        INT(11)       DEFAULT NULL,
    `priceBillingPeriodUnit`    VARCHAR(40)   DEFAULT NULL,
    `priceSubscriptionPeriod`   INT(11)       DEFAULT NULL,
    `priceSubscriptionPeriodUnit` VARCHAR(40) DEFAULT NULL,
    PRIMARY KEY (`priceSupplierItemId`, `minScale`, `priceSourceId`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_SupplierStockInfo`
(
    `supplierItemRefId`     BIGINT(20)   NOT NULL,
    `supplierRefId`         BIGINT(20)   NOT NULL,
    `stockSupplierText`     VARCHAR(40) DEFAULT NULL,
    `stockStatus`           INT(11)      NOT NULL,
    `stockStatusText`       VARCHAR(255) NOT NULL,
    `stock`                 INT(11)      NOT NULL,
    `externalStock`         INT(11)     DEFAULT NULL,
    `incomingStock`         INT(11)     DEFAULT NULL,
    `stockAvailabilityDate` DATETIME    DEFAULT NULL,
    `stockLastUpdate`       DATETIME     NOT NULL,
    `stockSourceId`         INT(11)      NOT NULL,
    `stockSourceName`       VARCHAR(255) NOT NULL,
    `stockUnlimited`        VARCHAR(5)   NOT NULL,
    PRIMARY KEY (`supplierItemRefId`, `stockSourceId`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_KeyContent`
(
    `key`                  BIGINT(20) NOT NULL,
    `langId`               BIGINT(20) NOT NULL,
    `contentModelRefId`    BIGINT(20) NOT NULL,
    `productRefId`         BIGINT(20) NOT NULL,
    `contentProviderRefId` BIGINT(20) NOT NULL,
    `contentCategoryRefId` BIGINT(20) NOT NULL,
    `value`                VARCHAR(255) DEFAULT NULL,
    `lang`                 VARCHAR(10)  DEFAULT NULL,
    PRIMARY KEY (`key`, `langId`, `contentModelRefId`, `contentCategoryRefId`, `productRefId`),
    KEY `kc_product` (`productRefId`),
    KEY `kc_contentModel` (`contentModelRefId`),
    KEY `kc_contentProvider` (`contentProviderRefId`),
    KEY `kc_contentCategory` (`contentCategoryRefId`),
    CONSTRAINT `kc_contentProvider` FOREIGN KEY (`contentProviderRefId`) REFERENCES `ITscope_ContentProvider` (`id`),
    CONSTRAINT `kc_contentCategory` FOREIGN KEY (`contentCategoryRefId`) REFERENCES `ITscope_ContentCategory` (`id`),
    CONSTRAINT `kc_contentModel` FOREIGN KEY (`contentModelRefId`) REFERENCES `ITscope_ContentModel` (`id`),
    CONSTRAINT `kc_product` FOREIGN KEY (`productRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_MediaContent`
(
    `key`                  BIGINT(20) NOT NULL,
    `langId`               BIGINT(20) NOT NULL,
    `contentModelRefId`    BIGINT(20) NOT NULL,
    `productRefId`         BIGINT(20) NOT NULL,
    `contentProviderRefId` BIGINT(20) NOT NULL,
    `contentCategoryRefId` BIGINT(20) NOT NULL,
    `contentTagRefId`      VARCHAR(60)   DEFAULT NULL,
    `value`                VARCHAR(1024) DEFAULT NULL,
    `lang`                 VARCHAR(10)   DEFAULT NULL,
    `mimeType`             VARCHAR(255)  DEFAULT NULL,
    `imageWidth`           INT(11)       DEFAULT NULL,
    `imageHeight`          INT(11)       DEFAULT NULL,
    PRIMARY KEY (`key`, `langId`, `contentModelRefId`, `productRefId`),
    KEY `mc_contentModel` (`contentModelRefId`),
    KEY `mc_product` (`productRefId`),
    KEY `mc_contentProvider` (`contentProviderRefId`),
    KEY `mc_contentCategory` (`contentCategoryRefId`),
    CONSTRAINT `mc_contentProvider` FOREIGN KEY (`contentProviderRefId`) REFERENCES `ITscope_ContentProvider` (`id`),
    CONSTRAINT `mc_contentCategory` FOREIGN KEY (`contentCategoryRefId`) REFERENCES `ITscope_ContentCategory` (`id`),
    CONSTRAINT `mc_contentModel` FOREIGN KEY (`contentModelRefId`) REFERENCES `ITscope_ContentModel` (`id`),
    CONSTRAINT `mc_product` FOREIGN KEY (`productRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_RatingContent`
(
    `key`                  BIGINT(20) NOT NULL,
    `langId`               BIGINT(20) NOT NULL,
    `contentModelRefId`    BIGINT(20) NOT NULL,
    `productRefId`         BIGINT(20) NOT NULL,
    `contentProviderRefId` BIGINT(20) NOT NULL,
    `contentTagRefId`      VARCHAR(255)  DEFAULT NULL,
    `value`                VARCHAR(1024) DEFAULT NULL,
    `lang`                 VARCHAR(10)   DEFAULT NULL,
    `unit`                 VARCHAR(20)   DEFAULT NULL,
    `deeplink`             VARCHAR(1024) DEFAULT NULL,
    PRIMARY KEY (`key`, `contentModelRefId`, `productRefId`, `langId`),
    KEY `rac_contentModel` (`contentModelRefId`),
    KEY `rac_product` (`productRefId`),
    KEY `rac_contentProvider` (`contentProviderRefId`),
    CONSTRAINT `rac_contentProvider` FOREIGN KEY (`contentProviderRefId`) REFERENCES `ITscope_ContentProvider` (`id`),
    CONSTRAINT `rac_contentModel` FOREIGN KEY (`contentModelRefId`) REFERENCES `ITscope_ContentModel` (`id`),
    CONSTRAINT `rac_product` FOREIGN KEY (`productRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_RefContent`
(
    `key`                  BIGINT(20) NOT NULL,
    `contentModelRefId`    BIGINT(20) NOT NULL,
    `productId`            BIGINT(20) NOT NULL,
    `contentProviderRefId` BIGINT(20) NOT NULL,
    `crossProductRefId`    BIGINT(20) NOT NULL,
    `typeId`               INT(11)      DEFAULT NULL,
    `type`                 VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`key`, `contentModelRefId`, `productId`, `crossProductRefId`),
    KEY `rc_contentModel` (`contentModelRefId`),
    KEY `rc_product` (`productId`),
    KEY `rc_contentProvider` (`contentProviderRefId`),
    CONSTRAINT `rc_contentProvider` FOREIGN KEY (`contentProviderRefId`) REFERENCES `ITscope_ContentProvider` (`id`),
    CONSTRAINT `rc_contentModel` FOREIGN KEY (`contentModelRefId`) REFERENCES `ITscope_ContentModel` (`id`),
    CONSTRAINT `rc_product` FOREIGN KEY (`productId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_TextContent`
(
    `key`                  BIGINT(20) NOT NULL,
    `langId`               BIGINT(20) NOT NULL,
    `contentModelRefId`    BIGINT(20) NOT NULL,
    `productRefId`         BIGINT(20) NOT NULL,
    `contentProviderRefId` BIGINT(20) NOT NULL,
    `contentCategoryRefId` BIGINT(20) NOT NULL,
    `contentTagRefId`      VARCHAR(60)  DEFAULT NULL,
    `value`                TEXT         DEFAULT NULL,
    `lang`                 VARCHAR(10)  DEFAULT NULL,
    `mimeType`             VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`key`, `langId`, `contentModelRefId`, `productRefId`),
    KEY `tc_contentModel` (`contentModelRefId`),
    KEY `tc_product` (`productRefId`),
    KEY `tc_contentProvider` (`contentProviderRefId`),
    KEY `tc_contentCategory` (`contentCategoryRefId`),
    CONSTRAINT `tc_contentCategory` FOREIGN KEY (`contentCategoryRefId`) REFERENCES `ITscope_ContentCategory` (`id`),
    CONSTRAINT `tc_contentModel` FOREIGN KEY (`contentModelRefId`) REFERENCES `ITscope_ContentModel` (`id`),
    CONSTRAINT `tc_contentProvider` FOREIGN KEY (`contentProviderRefId`) REFERENCES `ITscope_ContentProvider` (`id`),
    CONSTRAINT `tc_product` FOREIGN KEY (`productRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_AttributeUnit`
(
    `id`         VARCHAR(100) NOT NULL,
    `baseUnitId` VARCHAR(100) DEFAULT NULL,
    `mulFactor`  BIGINT(20)   DEFAULT NULL,
    `divFactor`  BIGINT(20)   DEFAULT NULL,
    PRIMARY KEY (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;


CREATE TABLE `ITscope_AttributeType`
(
    `id`                 BIGINT(20) NOT NULL,
    `name`               VARCHAR(255) DEFAULT NULL,
    `rank`               BIGINT(20)   DEFAULT NULL,
    `type`               BIGINT(20)   DEFAULT NULL,
    `attributeUnitRefId` VARCHAR(100) DEFAULT NULL,
    `groupId`            INT(11)      DEFAULT NULL,
    `groupName`          VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`),
    KEY `att_attributeUnit` (`attributeUnitRefId`),
    CONSTRAINT `att_attributeUnit` FOREIGN KEY (`attributeUnitRefId`) REFERENCES `ITscope_AttributeUnit` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_Attribute`
(
    `prodRefId`          BIGINT(20) NOT NULL,
    `value`              VARCHAR(1024) DEFAULT NULL,
    `displayValue`       VARCHAR(1024) DEFAULT NULL,
    `qualification`      BIGINT(20)    DEFAULT NULL,
    `attributeTypeRefId` BIGINT(20) NOT NULL,
    PRIMARY KEY (`prodRefId`, `attributeTypeRefId`),
    KEY `at_product` (`prodRefId`),
    KEY `at_attributeType` (`attributeTypeRefId`),
    CONSTRAINT `at_attributeType` FOREIGN KEY (`attributeTypeRefId`) REFERENCES `ITscope_AttributeType` (`id`),
    CONSTRAINT `at_product` FOREIGN KEY (`prodRefId`) REFERENCES `ITscope_Product` (`puid`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_Project`
(
    `projectSupplierItemId` BIGINT(20)  NOT NULL,
    `supplierProjectId`     VARCHAR(40) NOT NULL,
    `manufacturerProjectId` VARCHAR(40) NOT NULL,
    `projectName`           VARCHAR(40) DEFAULT NULL,
    `endCustomer`           VARCHAR(40) NOT NULL,
    `price`                 DOUBLE      NOT NULL,
    `validFrom`             DATETIME    DEFAULT NULL,
    `validTo`               DATETIME    DEFAULT NULL,
    `targetQuantity`        INT(8)      DEFAULT NULL,
    `remainingQuantity`     INT(8)      DEFAULT NULL,
    `minQuantity`           INT(8)      DEFAULT NULL,
    `projectLastUpdate`     DATETIME    DEFAULT NULL,
    `projectBundleId`       VARCHAR(50)    DEFAULT NULL,
	`projectBundleName`     VARCHAR(255)    DEFAULT NULL,
	`projectPosition`       INT(8)      DEFAULT NULL,
    PRIMARY KEY (`projectSupplierItemId`, `manufacturerProjectId`, `projectBundleId`, `projectPosition`),
    KEY `pr_supplItem` (`projectSupplierItemId`),
    CONSTRAINT `pr_supplItem` FOREIGN KEY (`projectSupplierItemId`) REFERENCES `ITscope_SupplierItem` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

CREATE TABLE `ITscope_ContractParameter`
(
    `supplierItemRefId`  BIGINT(20)   NOT NULL,
    `displayName`        VARCHAR(255) NOT NULL,
    `orderParameterName` VARCHAR(255) NOT NULL,
    `mandatory`          VARCHAR(5)   NOT NULL,
    `example`            VARCHAR(255) DEFAULT NULL,

    PRIMARY KEY (`supplierItemRefId`, `orderParameterName`),
    KEY `cp_supplItem` (`supplierItemRefId`),
    CONSTRAINT `cp_supplItem` FOREIGN KEY (`supplierItemRefId`) REFERENCES `ITscope_SupplierItem` (`id`)
)
    ENGINE = InnoDB
    DEFAULT CHARSET = latin1;

SET FOREIGN_KEY_CHECKS = 0;
TRUNCATE ITscope_AttributeCluster;
TRUNCATE ITscope_ContentCategory;
TRUNCATE ITscope_ContentModel;
TRUNCATE ITscope_ContentProvider;
TRUNCATE ITscope_ContentTag;
TRUNCATE ITscope_KeyContent;
TRUNCATE ITscope_Manufacturer;
TRUNCATE ITscope_Product;
TRUNCATE ITscope_ProductPriceInfo;
TRUNCATE ITscope_ProductStockInfo;
TRUNCATE ITscope_Products2Cluster;
TRUNCATE ITscope_RatingContent;
TRUNCATE ITscope_RefContent;
TRUNCATE ITscope_ProductType;
TRUNCATE ITscope_ProductTypeGroup;
TRUNCATE ITscope_Supplier;
TRUNCATE ITscope_SupplierItem;
TRUNCATE ITscope_SupplierPriceInfo;
TRUNCATE ITscope_SupplierStockInfo;
TRUNCATE ITscope_MediaContent;
TRUNCATE ITscope_TextContent;
TRUNCATE ITscope_AttributeUnit;
TRUNCATE ITscope_AttributeType;
TRUNCATE ITscope_Attribute;
TRUNCATE ITscope_Project;
TRUNCATE ITscope_ContractParameter;
SET FOREIGN_KEY_CHECKS = 1;